@echo off
REM cls
title Creo Purge 

rem - CREOPURGE.BAT [PATH] 
rem ================================================================
rem - Place this batch file in the c:\Utilities directory (create it if needed)
rem - 
rem - This batch program will run the Creo Parametric purge.bat file in
rem - the directory passed to it.
rem - 
rem - A valid starting path should be passed to this program.
rem - Edit the value of PURGECMD in this script to suit your environment
rem ================================================================
rem - Olaf Corten
rem - olaf.corten@creosite.com
rem ================================================================
rem - Rev.   Date	   Changes
rem - ----   -------   ---------------------------------------------
rem -  4.1   20201218  No longer pausing before Purging. 
rem                    Fixed error when calling with a dir with spaces. 
rem                    Now returning to origonal folder. 
rem -  4.0   20200727  Added NOEXT option. Set this to YES is you would like to remove the numerical extension after the purge.
rem -  3.2   20130920  Error message with wrong path now shows whole path.
rem -  3.1   20130114  Fixed bug: Added /D to cd command.
rem -  3.0   20130113  Started history
rem ================================================================

REM Customize the location of PTC's purge.bat to your environment
set PURGECMD=c:\PTC\Creo 4.0\M140\Parametric\bin\purge.bat
REM Set NOEXT to YES if you would like to remove the numerical extension after the purge: E.G. prt0001.prt.1 is renamed to prt0001.prt
set NOEXT=NO
set ORIGFOLDER=%CD%

if !%1==! goto nopath

if NOT EXIST "%PURGECMD%" goto nopurge


:start
  title Creo Purge in %*
  if NOT +%1==+. echo * Purging, %* 
  cd /D "%*"

  if NOT %ERRORLEVEL%==0 goto badpath


:nopath
  call "%PURGECMD%"
  IF "%NOEXT%"=="YES" goto noext
  goto complete

:noext
  echo.
  echo Removing numeric extensions ...
  echo.
  REM *.asm.* *.drw.* *.lay.* *.sec.* *.mfg.*
  for /f "eol=: delims=" %%A in ('dir /b /a-d *.???.*') do (
    REM Check the name of %%A
	for %%B in ("%%~nA") do (
		REM only when the  name has another extension (.prt, .asm, .drw, etc.)
		if NOT "%%~xB"=="" (
			REM check if the extension of the full name is numeric (greater than 0)
			if %%~xA GTR 0 do (
				echo ren %%~A %%~nA 
				ren %%~A %%~nA
			)
		)
	)
  )
  goto complete

:nopurge
  echo.
  echo ERROR - Cannot find %PURGECMD% ....
  echo.
  echo You must edit %0 to point to the correct location of purge.bat
  goto complete

:badpath
  echo.
  echo ERROR - "%*" is not a valid path....
  echo.
  echo You must provide a valid path when calling %0
  goto complete

:complete
  echo Creo Purge complete ...
  cd /D "%ORIGFOLDER%"
  if NOT +%1==+. pause
  REM exit /B